powered by
Creates an Rmarkdown template with the HTML structure required by screen readers.
access_rmd( filenm = NULL, title = NULL, subtitle = NULL, lan = NULL, author = Sys.info()[8], date = format(Sys.Date(), "%d %b %Y"), toc = FALSE, encoding = "utf-8", force = FALSE, theme = "default", highlight = "null" )
Required - The name of the file.
Required - The document title.
Optional - The document subtitle.
Required - The HTML language to set as the value for the lang attribute.
Required - The document author. Defaults to the effective user identified by Sys.info().
Sys.info()
Required - The author date. Defaults to today's date.
Optional, defaults to FALSE. Should a table of contents be included. Valid entries are FALSE (the default) or TRUE.
Defaults to "utf-8".
Defaults to FALSE. If TRUE, overwrites a pre-existing file with the same filenm with warning.
Set to "default", currently the only in-built theme that does not result in accessibility errors.
Set to "null", currently the only in-built highlight that does not result in accessibility errors.
An Rmarkdown file with an HTML head, populated with metadata specified within the function parameters.
# NOT RUN { # create an accessible rmarkdown document from scratch access_rmd( "some_filenm", title = "Title Goes Here", lan = "en", author = "Author here" ) # } # NOT RUN { # }
Run the code above in your browser using DataLab