handle_rmd_path: Check rmd path & file type.
Description
Checks rmd_path exists and that the file suffix is correct.
Usage
handle_rmd_path(rmd_path = NULL)
Arguments
rmd_path
Path to the Rmd to check.
Value
Reads rmd lines on success. Error if file does not exist or is not an
rmd file.